==> koshoten.net-2.1.3.tar.gz: koshoten-net/catalog/includes/modules/kn_shipping/yamato.php <==
<?php
/*
  $Id: yamato.php,v 1.1.1.1 2005/06/30 05:04:20 ryu Exp $

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2003 osCommerce

  Released under the GNU General Public License
*/
//
// ⥸塼 ޥ
// TAMURA Toshihiko (tamura@bitscope.co.jp)
//
// [Ϣե]
// catalog/includes/classes/_yamato.php
// catalog/includes/languages/japanese/modules/shipping/yamato.php
// catalog/includes/modules/shipping/yamato.php
// catalog/images/icons/shipping_yamato.gif
//
// []
// http://www.kuronekoyamato.co.jp/
//
// [] by RyuheiAoki 2004/12/02
// 0ΤȤս񤭤ɲ
//
  class yamato {
    var $code, $title, $description, $sort_order, $icon, $tax_class, $enabled;
    var $yamato_countries, $yamato_countries_nbr;
    var $quote;

// class constructor
    function yamato() {
      global $order;

      $this->code        = 'yamato';
      $this->title       = MODULE_SHIPPING_YAMATO_TEXT_TITLE;
      $this->description = MODULE_SHIPPING_YAMATO_TEXT_DESCRIPTION;
      $this->sort_order  = MODULE_SHIPPING_YAMATO_SORT_ORDER;
      $this->icon        = DIR_WS_ICONS . 'shipping_yamato.gif';
      $this->tax_class   = in_array('MODULE_SHIPPING_YAMATO_TAX_CLASS',$this->keys()) ? MODULE_SHIPPING_YAMATO_TAX_CLASS : 0;
      $this->enabled     = MODULE_SHIPPING_YAMATO_D_STATUS;

      // only these three are needed since Yamato only ships to them
      // convert TEP country id to ISO 3166 id
      $this->yamato_countries = array(107 => 'JP');
      $this->yamato_countries_nbr = array(107);

      if ( ($this->enabled == true) && ((int)MODULE_SHIPPING_YAMATO_ZONE > 0) ) {
        $check_flag = false;
        $check_query = tep_db_query("select zone_id from " . TABLE_ZONES_TO_GEO_ZONES . " where geo_zone_id = '" . MODULE_SHIPPING_YAMATO_ZONE . "' and zone_country_id = '" . $order->delivery['country']['id'] . "' order by zone_id");
        while ($check = tep_db_fetch_array($check_query)) {
          if ($check['zone_id'] < 1) {
            $check_flag = true;
            break;
          } elseif ($check['zone_id'] == $order->delivery['zone_id']) {
            $check_flag = true;
            break;
          }
        }

        if ($check_flag == false) {
          $this->enabled = false;
        }
      }
    }

// class methods
    function quote() {
      global $shipping_weight, $shipping_num_boxes;
      global $order;
      global $a_yamato_time;
      global $cart;

      $this->quotes = array('id' => $this->code,
                            'module' => $this->title);
      if (tep_not_null($this->icon)) $this->quotes['icon'] = tep_image($this->icon, $this->title);

      $country_id = $order->delivery['country']['id'];
      $zone_id    = $order->delivery['zone_id'];

      if (in_array($country_id, $this->yamato_countries_nbr)) {
          $zoneinfo = tep_db_query("SELECT zone_code FROM zones WHERE zone_id = '".$zone_id."'");
          $a_zonevalues = tep_db_fetch_array($zoneinfo);
          $s_zone_code = $a_zonevalues['zone_code'];

          if ( (MODULE_SHIPPING_YAMATO_FREE_SHIPPING != 'True') || ((int)$cart->show_total() < (int)MODULE_SHIPPING_YAMATO_OVER) ) {
              include(DIR_WS_CLASSES . '_yamato.php');
              $rate = new _Yamato($this->code, MODULE_SHIPPING_YAMATO_TEXT_WAY_NORMAL,
                                STORE_ORIGIN_ZONE, STORE_ORIGIN_COUNTRY);
              $rate->SetDest($s_zone_code, $this->yamato_countries[$country_id]);
              $rate->SetWeight($shipping_weight);
              $tmpQuote = $rate->GetQuote(); // id, title, cost | error

              if (isset($tmpQuote['error'])) {
                  $this->quotes['error'] = $tmpQuote['error'];
              } else {
// BOF koshoten.net-2.0.0
// ̤б
/*
                  $this->quotes['module'] = $this->title
                      . ' (' . $shipping_num_boxes . ' x ' . $shipping_weight . 'kg)';

                  $tmpQuote['cost'] *= $shipping_num_boxes;
                  // ǥ
                  if (defined('MODULE_SHIPPING_YAMATO_DISCOUNT') && 0 < (int)MODULE_SHIPPING_YAMATO_DISCOUNT) {
                      $tmpQuote['cost'] -= (int)($tmpQuote['cost'] * MODULE_SHIPPING_YAMATO_DISCOUNT / 100);
                  }
                  // 
                  $tmpQuote['cost'] += MODULE_SHIPPING_YAMATO_HANDLING;

*/
                  // ̤ΤȤϡ̤
                  if (!$shipping_weight) {
                    $this->quotes['module'] = $this->title . MODULE_SHIPPING_YAMATO_TEXT_GET_QUOTE_LATER;
                    $tmpQuote['cost'] = 0;
                  } else {
                    $this->quotes['module'] = $this->title
                          . ' (' . $shipping_num_boxes . ' x ' . $shipping_weight . 'kg)';

                      $tmpQuote['cost'] *= $shipping_num_boxes;
                      // ǥ
                      if (defined('MODULE_SHIPPING_YAMATO_DISCOUNT') && 0 < (int)MODULE_SHIPPING_YAMATO_DISCOUNT) {
                          $tmpQuote['cost'] -= (int)($tmpQuote['cost'] * MODULE_SHIPPING_YAMATO_DISCOUNT / 100);
                      }
                      // 
                      $tmpQuote['cost'] += MODULE_SHIPPING_YAMATO_HANDLING;
                  }
// EOF koshoten.net-2.0.0
              }
          } else {
              $tmpQuote = array('id' => $this->code, 'title' => MODULE_SHIPPING_YAMATO_TEXT_WAY_NORMAL, 'cost' => 0);
          }

          if (!isset($tmpQuote['error'])) {
              // 
              $timespec = $this->get_timespec();
              $tmpQuote['option'] = TEXT_TIME_SPECIFY
                  . tep_draw_pull_down_menu('yamato_timespec', $a_yamato_time, $timespec);
              $tmpQuote['timespec'] = $timespec;
          }

          $this->quotes['methods'][] = $tmpQuote;

          if ($this->tax_class > 0) {
              $this->quotes['tax'] = tep_get_tax_rate($this->tax_class, $country_id, $zone_id);
          }
        } else {
            $this->quotes['error'] = MODULE_SHIPPING_YAMATO_TEXT_NOTAVAILABLE;
        }

        return $this->quotes;
    }

    // ꤹץ˥塼'value'֤
    function get_timespec() {
        global $a_yamato_time;
        global $shipping;
        global $HTTP_POST_VARS;

        $selected = $a_yamato_time[0]['id'];
        if ( isset($HTTP_POST_VARS['yamato_timespec']) ) {
            $selected = $HTTP_POST_VARS['yamato_timespec'];
        } elseif ( is_array($shipping) ) { // see checkout_shipping.php
            list($module, $method) = explode('_', $shipping['id']);
            if ($module == $this->code) {
                $selected = $shipping['timespec'];
            }
        }
        return $selected;
    }

    function check() {
      if (!isset($this->_check)) {
        $check_query = tep_db_query("select configuration_value from "
          . TABLE_CONFIGURATION . " where configuration_key = 'MODULE_SHIPPING_YAMATO_STATUS'");
        $this->_check = tep_db_num_rows($check_query);
      }
      return $this->_check;
    }

    function install() {
      tep_db_query("insert into " . TABLE_CONFIGURATION .
      " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('ޥؤͭˤ', 'MODULE_SHIPPING_YAMATO_STATUS', 'True', 'ޥؤ󶡤ޤ?', '6', '0', 'tep_cfg_select_option(array(\'True\', \'False\'), ', now())");

      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('谷', 'MODULE_SHIPPING_YAMATO_HANDLING', '0', 'ŬѤ谷Ǥޤ.', '6', '1', now())");

      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('̵', 'MODULE_SHIPPING_YAMATO_FREE_SHIPPING', 'False', '̵ͭˤޤ? [ץ⥸塼]-[]-[̵]ͥ褹 False Ǥ.', '6', '2', 'tep_cfg_select_option(array(\'True\', \'False\'), ', now())");

      tep_db_query("INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('̵ˤ', 'MODULE_SHIPPING_YAMATO_OVER', '5000', '۰ʾ򤴹ξ̵ˤޤ.', '6', '3', now())");

      tep_db_query("INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('ͰΨ', 'MODULE_SHIPPING_YAMATO_DISCOUNT', '0', 'ͰΨꤷޤ.()', '6', '4', now())");

//    tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, use_function, set_function, date_added) values ('Ǽ', 'MODULE_SHIPPING_YAMATO_TAX_CLASS', '0', 'ŬѤǼ̤Ǥ.', '6', '5', 'tep_get_tax_class_title', 'tep_cfg_pull_down_tax_classes(', now())");

      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, use_function, set_function, date_added) values ('ϰ', 'MODULE_SHIPPING_YAMATO_ZONE', '0', 'ϰ򤹤򤵤줿ϰΤߤѲǽȤʤޤ.', '6', '6', 'tep_get_zone_class_title', 'tep_cfg_pull_down_zone_classes(', now())");

      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('ɽ', 'MODULE_SHIPPING_YAMATO_SORT_ORDER', '0', 'ɽǤޤ. ۤɾ̤ɽޤ.', '6', '7', now())");
    }

    function remove() {
      tep_db_query("delete from " . TABLE_CONFIGURATION . " where configuration_key in ('" . implode("', '", $this->keys()) . "')");
    }

    function keys() {
      return array(
        'MODULE_SHIPPING_YAMATO_STATUS',
        'MODULE_SHIPPING_YAMATO_HANDLING',
        'MODULE_SHIPPING_YAMATO_FREE_SHIPPING',
        'MODULE_SHIPPING_YAMATO_OVER',
        'MODULE_SHIPPING_YAMATO_DISCOUNT',
//      'MODULE_SHIPPING_YAMATO_TAX_CLASS',
        'MODULE_SHIPPING_YAMATO_ZONE',
        'MODULE_SHIPPING_YAMATO_SORT_ORDER',
      );
    }
  }
?>

==> koshoten.net-2.1.5.tar.gz: koshoten-net/catalog/includes/modules/kn_shipping/yamato.php <==
<?php
/*
  $Id: yamato.php,v 1.2 2006/01/29 14:49:24 ryu Exp $

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2003 osCommerce

  Released under the GNU General Public License
*/
//
// ⥸塼 ޥ
// TAMURA Toshihiko (tamura@bitscope.co.jp)
//
// [Ϣե]
// catalog/includes/classes/_yamato.php
// catalog/includes/languages/japanese/modules/shipping/yamato.php
// catalog/includes/modules/shipping/yamato.php
// catalog/images/icons/shipping_yamato.gif
//
// []
// http://www.kuronekoyamato.co.jp/
//
// [] by RyuheiAoki 2004/12/02
// 0ΤȤս񤭤ɲ
//
  class yamato {
    var $code, $title, $description, $sort_order, $icon, $tax_class, $enabled;
    var $yamato_countries, $yamato_countries_nbr;
    var $quote;

// class constructor
    function yamato() {
      global $order;

      $this->code        = 'yamato';
      $this->title       = MODULE_SHIPPING_YAMATO_TEXT_TITLE;
      $this->description = MODULE_SHIPPING_YAMATO_TEXT_DESCRIPTION;
      $this->sort_order  = MODULE_SHIPPING_YAMATO_SORT_ORDER;
      $this->icon        = DIR_WS_ICONS . 'shipping_yamato.gif';
      $this->tax_class   = in_array('MODULE_SHIPPING_YAMATO_TAX_CLASS',$this->keys()) ? MODULE_SHIPPING_YAMATO_TAX_CLASS : 0;
      $this->enabled     = ((MODULE_SHIPPING_YAMATO_STATUS == 'True') ? true : false);

      // only these three are needed since Yamato only ships to them
      // convert TEP country id to ISO 3166 id
      $this->yamato_countries = array(107 => 'JP');
      $this->yamato_countries_nbr = array(107);

      if ( ($this->enabled == true) && ((int)MODULE_SHIPPING_YAMATO_ZONE > 0) ) {
        $check_flag = false;
        $check_query = tep_db_query("select zone_id from " . TABLE_ZONES_TO_GEO_ZONES . " where geo_zone_id = '" . MODULE_SHIPPING_YAMATO_ZONE . "' and zone_country_id = '" . $order->delivery['country']['id'] . "' order by zone_id");
        while ($check = tep_db_fetch_array($check_query)) {
          if ($check['zone_id'] < 1) {
            $check_flag = true;
            break;
          } elseif ($check['zone_id'] == $order->delivery['zone_id']) {
            $check_flag = true;
            break;
          }
        }

        if ($check_flag == false) {
          $this->enabled = false;
        }
      }
    }

// class methods
    function quote() {
      global $shipping_weight, $shipping_num_boxes;
      global $order;
      global $a_yamato_time;
      global $cart;

      $this->quotes = array('id' => $this->code,
                            'module' => $this->title);
      if (tep_not_null($this->icon)) $this->quotes['icon'] = tep_image($this->icon, $this->title);

      $country_id = $order->delivery['country']['id'];
      $zone_id    = $order->delivery['zone_id'];

      if (in_array($country_id, $this->yamato_countries_nbr)) {
          $zoneinfo = tep_db_query("SELECT zone_code FROM zones WHERE zone_id = '".$zone_id."'");
          $a_zonevalues = tep_db_fetch_array($zoneinfo);
          $s_zone_code = $a_zonevalues['zone_code'];

          if ( (MODULE_SHIPPING_YAMATO_FREE_SHIPPING != 'True') || ((int)$cart->show_total() < (int)MODULE_SHIPPING_YAMATO_OVER) ) {
              include(DIR_WS_CLASSES . '_yamato.php');
              $rate = new _Yamato($this->code, MODULE_SHIPPING_YAMATO_TEXT_WAY_NORMAL,
                                STORE_ORIGIN_ZONE, STORE_ORIGIN_COUNTRY);
              $rate->SetDest($s_zone_code, $this->yamato_countries[$country_id]);
              $rate->SetWeight($shipping_weight);
              $tmpQuote = $rate->GetQuote(); // id, title, cost | error

              if (isset($tmpQuote['error'])) {
                  $this->quotes['error'] = $tmpQuote['error'];
              } else {
// BOF koshoten.net-2.0.0
// ̤б
/*
                  $this->quotes['module'] = $this->title
                      . ' (' . $shipping_num_boxes . ' x ' . $shipping_weight . 'kg)';

                  $tmpQuote['cost'] *= $shipping_num_boxes;
                  // ǥ
                  if (defined('MODULE_SHIPPING_YAMATO_DISCOUNT') && 0 < (int)MODULE_SHIPPING_YAMATO_DISCOUNT) {
                      $tmpQuote['cost'] -= (int)($tmpQuote['cost'] * MODULE_SHIPPING_YAMATO_DISCOUNT / 100);
                  }
                  // 
                  $tmpQuote['cost'] += MODULE_SHIPPING_YAMATO_HANDLING;

*/
                  // ̤ΤȤϡ̤
                  if (!$shipping_weight) {
                    $this->quotes['module'] = $this->title . MODULE_SHIPPING_YAMATO_TEXT_GET_QUOTE_LATER;
                    $tmpQuote['cost'] = 0;
                  } else {
                    $this->quotes['module'] = $this->title
                          . ' (' . $shipping_num_boxes . ' x ' . $shipping_weight . 'kg)';

                      $tmpQuote['cost'] *= $shipping_num_boxes;
                      // ǥ
                      if (defined('MODULE_SHIPPING_YAMATO_DISCOUNT') && 0 < (int)MODULE_SHIPPING_YAMATO_DISCOUNT) {
                          $tmpQuote['cost'] -= (int)($tmpQuote['cost'] * MODULE_SHIPPING_YAMATO_DISCOUNT / 100);
                      }
                      // 
                      $tmpQuote['cost'] += MODULE_SHIPPING_YAMATO_HANDLING;
                  }
// EOF koshoten.net-2.0.0
              }
          } else {
              $tmpQuote = array('id' => $this->code, 'title' => MODULE_SHIPPING_YAMATO_TEXT_WAY_NORMAL, 'cost' => 0);
          }

          if (!isset($tmpQuote['error'])) {
              // 
              $timespec = $this->get_timespec();
              $tmpQuote['option'] = TEXT_TIME_SPECIFY
                  . tep_draw_pull_down_menu('yamato_timespec', $a_yamato_time, $timespec);
              $tmpQuote['timespec'] = $timespec;
          }

          $this->quotes['methods'][] = $tmpQuote;

          if ($this->tax_class > 0) {
              $this->quotes['tax'] = tep_get_tax_rate($this->tax_class, $country_id, $zone_id);
          }
        } else {
            $this->quotes['error'] = MODULE_SHIPPING_YAMATO_TEXT_NOTAVAILABLE;
        }

        return $this->quotes;
    }

    // ꤹץ˥塼'value'֤
    function get_timespec() {
        global $a_yamato_time;
        global $shipping;
        global $HTTP_POST_VARS;

        $selected = $a_yamato_time[0]['id'];
        if ( isset($HTTP_POST_VARS['yamato_timespec']) ) {
            $selected = $HTTP_POST_VARS['yamato_timespec'];
        } elseif ( is_array($shipping) ) { // see checkout_shipping.php
            list($module, $method) = explode('_', $shipping['id']);
            if ($module == $this->code) {
                $selected = $shipping['timespec'];
            }
        }
        return $selected;
    }

    function check() {
      if (!isset($this->_check)) {
        $check_query = tep_db_query("select configuration_value from "
          . TABLE_CONFIGURATION . " where configuration_key = 'MODULE_SHIPPING_YAMATO_STATUS'");
        $this->_check = tep_db_num_rows($check_query);
      }
      return $this->_check;
    }

    function install() {
      tep_db_query("insert into " . TABLE_CONFIGURATION .
      " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('ޥؤͭˤ', 'MODULE_SHIPPING_YAMATO_STATUS', 'True', 'ޥؤ󶡤ޤ?', '6', '0', 'tep_cfg_select_option(array(\'True\', \'False\'), ', now())");

      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('谷', 'MODULE_SHIPPING_YAMATO_HANDLING', '0', 'ŬѤ谷Ǥޤ.', '6', '1', now())");

      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('̵', 'MODULE_SHIPPING_YAMATO_FREE_SHIPPING', 'False', '̵ͭˤޤ? [ץ⥸塼]-[]-[̵]ͥ褹 False Ǥ.', '6', '2', 'tep_cfg_select_option(array(\'True\', \'False\'), ', now())");

      tep_db_query("INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('̵ˤ', 'MODULE_SHIPPING_YAMATO_OVER', '5000', '۰ʾ򤴹ξ̵ˤޤ.', '6', '3', now())");

      tep_db_query("INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('ͰΨ', 'MODULE_SHIPPING_YAMATO_DISCOUNT', '0', 'ͰΨꤷޤ.()', '6', '4', now())");

//    tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, use_function, set_function, date_added) values ('Ǽ', 'MODULE_SHIPPING_YAMATO_TAX_CLASS', '0', 'ŬѤǼ̤Ǥ.', '6', '5', 'tep_get_tax_class_title', 'tep_cfg_pull_down_tax_classes(', now())");

      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, use_function, set_function, date_added) values ('ϰ', 'MODULE_SHIPPING_YAMATO_ZONE', '0', 'ϰ򤹤򤵤줿ϰΤߤѲǽȤʤޤ.', '6', '6', 'tep_get_zone_class_title', 'tep_cfg_pull_down_zone_classes(', now())");

      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('ɽ', 'MODULE_SHIPPING_YAMATO_SORT_ORDER', '0', 'ɽǤޤ. ۤɾ̤ɽޤ.', '6', '7', now())");
    }

    function remove() {
      tep_db_query("delete from " . TABLE_CONFIGURATION . " where configuration_key in ('" . implode("', '", $this->keys()) . "')");
    }

    function keys() {
      return array(
        'MODULE_SHIPPING_YAMATO_STATUS',
        'MODULE_SHIPPING_YAMATO_HANDLING',
        'MODULE_SHIPPING_YAMATO_FREE_SHIPPING',
        'MODULE_SHIPPING_YAMATO_OVER',
        'MODULE_SHIPPING_YAMATO_DISCOUNT',
//      'MODULE_SHIPPING_YAMATO_TAX_CLASS',
        'MODULE_SHIPPING_YAMATO_ZONE',
        'MODULE_SHIPPING_YAMATO_SORT_ORDER',
      );
    }
  }
?>
